
*		************************************************************************		*
*		************************************************************************		*
*		  File:				main.do														*
*		  Date:				February 2017												*
*		  Author:			MG															*
*		  Purpose:			Turnout effect (i-voting)									*
*		  Log file:			log.log														*
*		  Data output:		None														*
*		  Machine:			Office laptop												*
*		  Stata version:	14															*
*		************************************************************************		*
*		************************************************************************		*



* Directory
set more off
global directory = "D:\Dropbox\I-voting and turnout\Replication"  /* Plug in directory */
cd "$directory"

* Log file
capture log close
log using "log.log", replace

* Packages
ssc install spmap, replace
ssc install shp2dta, replace
ssc install psmatch2, replace
ssc install xtivreg2, replace
ssc install ivreg2, replace
ssc install ranktest, replace
ssc install labutil, replace
findit lean2 /* Manual installation */




**********
** Table 1
**********

* (1) Geneva
use "Data\Geneva_final.dta", replace
xtreg turnout ivote_poss ///
	i.date unittrend6601-unittrend6644 unittrendsq6601-unittrendsq6644 ///
	, ///
	fe cl(municipality_code) i(municipality_code)

* (2) Zurich	
use "Data\Zurich_final.dta", replace
xtreg turnout ivote_poss ///
	i.date unittrend1-unittrend251 unittrendsq1-unittrendsq251 ///
	, ///
	fe cl(municipality_code) i(municipality_code) 

	

	
**********
** Table 2
**********

* (1) Geneva (+RHS)
use "Data\Geneva_final.dta", replace
xtreg turnout ivote_poss ///
	i.date unittrend6601-unittrend6644 unittrendsq6601-unittrendsq6644 ///
	logpop foreigners_share below35 above65 ///
	loginc unemployed sp_voteshare gps_voteshare ///
	, ///
	fe cl(municipality_code) i(municipality_code) 
	
* (2) Zurich (+RHS)
use "Data\Zurich_final.dta", replace
xtreg turnout ivote_poss ///
	i.date unittrend1-unittrend251 unittrendsq1-unittrendsq251 ///
	logpop foreigners_share below35 above65 ///
	loginc unemployed sp_voteshare gps_voteshare ///
	, ///
	fe cl(municipality_code) i(municipality_code)

* (3) Geneva (Matched samples)
use "Data\Geneva_final.dta", replace
do "Ancillary do files\Matching_GE.do"
xtreg turnout ivote_poss ///
	i.date unittrend6601-unittrend6644 unittrendsq6601-unittrendsq6644 ///
	[fweight=weight], ///
	fe cl(municipality_code) i(municipality_code)

* (4) Zurich (Matched samples)
use "Data\Zurich_final.dta", replace
do "Ancillary do files\Matching_ZH.do"
xtreg turnout ivote_poss ///
	i.date unittrend1-unittrend251 unittrendsq1-unittrendsq251 ///
	[fweight=weight], ///
	fe cl(municipality_code) i(municipality_code) 

* (5) Geneva (2-way clustered ses)
use "Data\Geneva_final.dta", replace
tab date, gen(datedummy)
xtivreg2 turnout ivote_poss ///
	datedummy* unittrend6601-unittrend6644 unittrendsq6601-unittrendsq6644 ///
	, ///
	fe ivar(municipality_code) clu(municipality_code date) 

* (6) Zurich (2-way clustered ses)
use "Data\Zurich_final.dta", replace
tab date, gen(datedummy)
xtivreg2 turnout ivote_poss ///
	datedummy* unittrend1-unittrend251 unittrendsq1-unittrendsq251 ///
	, ///
	fe ivar(municipality_code) clu(municipality_code date) 

* (7) Geneva (Turnout among young voters)
use "Data\Geneva_final.dta", replace
xtreg yturnout ivote_poss ///
	i.date unittrend6601-unittrend6644 unittrendsq6601-unittrendsq6644 ///
	, ///
	fe cl(municipality_code) i(municipality_code)


* (8) Geneva (Turnout among old voters)
use "Data\Geneva_final.dta", replace
xtreg eturnout ivote_poss ///
	i.date unittrend6601-unittrend6644 unittrendsq6601-unittrendsq6644 ///
	, ///
	fe cl(municipality_code) i(municipality_code)



***********
** Figure 1
***********


* a)
use "Data\Geneva_final.dta", replace

* Change to geo directory
cd "$directory\Data\Geo"

* Create file with municipality number and info on i-voting
collapse ivotemun (sum) ivote_poss, by(municipality_code)
save "ivoteinfoGE.dta", replace

* Draw map
shp2dta using g2g13, data("swidata") coor("swicoordinates") genid(id_shp) replace genc(c)
use "swidata.dta", replace
keep if KTNR == 25
rename GMDNR municipality_code
merge 1:1 municipality_code using "ivoteinfoGE.dta"

spmap ivote_poss using "swicoordinates" if municipality_code < 9000, /// /* if condition excludes lakes */, ///
	id(id_shp) ///
	clmethod(custom) clbreaks(0 0.25 5.25 10.25 15.25 22.25) fcolor(gs16 gs13 gs10 gs7 gs4) ///
	legend(pos(11) size(*1.8) symxsize(*1.8) symysize(*1.8) ///
	order(- "Number of trials:" 2 3 4 5 6) ///	
	label(2 "0") label(3 "1-5") label(4 "6-10") label(5 "11-15") label(6 "16-22")) ///
	title("Geneva", margin(bottom) size(vlarge)) ///
	plotregion(margin(medlarge)) xsize(6) ysize(8)
gr_edit .legend.plotregion1.label[1].xoffset = -7.1
gr_edit .legend.plotregion1.label[1].yoffset = 1
gr_edit .style.editstyle aspect_pos(north) editcopy
gr_edit .title.style.editstyle margin(top_bottom) editcopy

* Change directory back and export graph
cd "$directory"
graph export "Figures\Map_GE.pdf", replace


* b)
use "Data\Zurich_final.dta", replace

* Change to geo directory
cd "$directory\Data\Geo"

* Create file with municipality number and info on i-voting
collapse ivotemun (sum) ivote_poss, by(municipality_code)
save "ivoteinfoZH.dta", replace

* Draw map
shp2dta using g2g13, data("swidata") coor("swicoordinates") genid(id_shp) replace genc(c)
use "swidata.dta", replace
keep if KTNR == 1
rename GMDNR municipality_code
merge 1:1 municipality_code using "ivoteinfoZH.dta" /* The two that do not match are lakes */

spmap ivote_poss using "swicoordinates" if municipality_code < 9000, /// /* if condition excludes lakes */
	id(id_shp) ///
	clmethod(custom) clbreaks(0 0.25 5.25 10.25 15.25 22.25) fcolor(gs16 gs13 gs10 gs7 gs4) ///
	legend(pos(11) size(*1.8) symxsize(*1.8) symysize(*1.8) ///
	order(- "Number of trials:" 2 3 4 5 6) ///	
	label(2 "0") label(3 "1-5") label(4 "6-10") label(5 "11-15") label(6 "16-22")) ///
	title("Zurich", margin(bottom) size(vlarge)) ///
	plotregion(margin(medlarge)) xsize(6) ysize(8)
gr_edit .legend.plotregion1.label[1].xoffset = -7.1
gr_edit .legend.plotregion1.label[1].yoffset = 1
gr_edit .style.editstyle aspect_pos(north)
gr_edit .title.style.editstyle margin(top_bottom) editcopy
gr_edit .legend.plotregion1.key[5].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.key[5].fill_if_undrawn.setstyle, style(yes)
gr_edit .legend.plotregion1.label[6].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[6].fill_if_undrawn.setstyle, style(yes)

* Change directory back and export graph
cd "$directory"
graph export "Figures\Map_ZH.pdf", replace


* c)
use "Data\Geneva_final.dta", replace

* Drop municipalities without an i-voting trial
drop if ivotemun == 0

* Drop votes before first trial
drop if date < datefirsttrial_fed

* Generate an alternative numeric municipality code starting from 1
decode municipality_code, gen(municipality_code1)
encode municipality_code1, gen(municipality_code2)

* Draw graph
twoway 	(scatter municipality_code2 date if ivote_poss == 0) ///
		(scatter municipality_code2 date if  ivote_poss == 1, mcolor(gs0)), ///
			xscale(noextend) yscale(reverse noextend) ///
			xlabel(16071 16437 16802 17167 17532 17898 ///
					18263 18628 18993 19359 19724 20089, angle(forty_five) value) ///
			xmlabel(16162 16253 16345 16527 16618 16710 16892 16983 17075 ///
					17257 17348 17440 17623 17714 17806 17988 18079 18171 18353 18444 18536 18718 18809 ///
					18901 19084 19175 19267 19449 19540 19632 19814 19905 19997, nolabels) ///
			ylabel(1(1)20, valuelabel nogrid) ///
			xtitle("Time") ytitle("") ///
			title("Geneva", margin(bottom) size(vlarge)) ///
			plotregion(margin(medlarge)) ///
			legend(order(2 "I-voting trials" 1 "Gaps") rows(1) pos(12) region(lcolor(white))) /// 
			scheme(lean2) xsize(8) ysize(8) scale(*.8)
graph export "Figures\Trialoverview_inclgaps_GE_onlyfederalreferendums.pdf", replace

* d)
use "Data\Zurich_final.dta", replace

* Drop municipalities without an i-voting trial
drop if ivotemun == 0

* Drop votes before first trial
drop if date < datefirsttrial_fed

* Generate an alternative numeric municipality code starting from 1
decode municipality_code, gen(municipality_code1)
encode municipality_code1, gen(municipality_code2)

* Draw graph
twoway scatter municipality_code2 date if ivote_poss == 0, mcolor(gs0) ///
	|| 	scatter municipality_code2 date if ivote_poss == 1, mcolor(gs0) ///
	, ///
		xscale(noextend) yscale(reverse noextend) ///
		xlabel(16437 16802 17167 17532 17898  ///
			18263 18628 18993, angle(forty_five) value) ///
		xmlabel(16527 16618 16710 16892 16983 17075 17257 17348 ///
			17440 17623 17714 17806 17988 18079 18171 18353 18444 18536 18718 18809 ///
			18901, nolabels) ///
		ylabel(1(1)13, valuelabel nogrid) ///
		xtitle("Time") ytitle("") ///
		title("Zurich", margin(bottom) size(vlarge)) ///
		plotregion(margin(medlarge)) ///
		legend(order(2 "I-voting trials" 1 "Gaps") rows(1) pos(12) region(lcolor(white))) ///
		scheme(lean2) xsize(8) ysize(8) scale(*.8)
graph export "Figures\Trialoverview_inclgaps_ZH_onlyfederalreferendums.pdf", replace






***********
** Figure 2
***********

* Geneva
use "Data\Geneva_final.dta", replace	

* Drop observations after first post-big gap (2005-2008) trial
drop if date >= td(30nov2008)

* Drop the two trials before big gap
drop if date == td(26sep2004)
drop if date == td(28nov2004)

* Mean by treatment group
collapse turnout, by(ivotemun date year month day)

* Small ticks for Apr 1st, Jul 1st and Oct 1st
forval i = 2001/2008 { 
di d(1apr`i') " " _c 
di d(1jul`i') " " _c 
di d(1oct`i') " " _c
}

twoway 	(connected turnout date if ivotemun == 1 & date < td(26sep2004), ///
			sort lpattern(solid) lcolor(gs0) mcolor(gs0) msymbol(circle)) ///
		(connected turnout date if ivotemun == 1 & date > td(26sep2004), ///
			sort lpattern(solid) lcolor(gs0) mcolor(gs0) msymbol(circle)) ///
		(connected turnout date if ivotemun == 0 & date < td(26sep2004), ///
			sort lpattern(dash) lcolor(gs8) mcolor(gs8) msymbol(circle)) ///
		(connected turnout date if ivotemun == 0 & date > td(26sep2004), ///
			sort lpattern(dash) lcolor(gs8) mcolor(gs8) msymbol(circle)), ///
		xscale(nofextend) ///
		xlabel(14976 15341 15706 16071 16437 16071 16437 16802 17167 17532 ///
				17898, nogrid angle(forty_five) value) ///
		xmlabel(15249 15431 15522 15614 15796 15887 15979 16162 16253 16345 ///
				16527 16618 16710 16892 16983 17075 17257 17348 17440 17623 17714 17806 ///
				, nolabels) ///
		xtitle("Time", margin(small)) ///
		yscale(nofextend) ///
		ylabel(20(10)80, angle(horizontal) nogrid) ///
		ymlabel(22.5(2.5)77.5, nolabels) ///
		ytitle("Turnout (%)", margin(small)) ///
		title("Geneva", margin(bottom) size(vlarge)) ///
		scheme(s2mono) graphregion(fcolor(white) lcolor(white)) ///
		legend(order(1 "I-voting" 3 "No i-voting") rows(1) pos(12) region(lcolor(white)))
graph export "Figures\paralleltrends_GE_turnout.pdf", replace


* Zurich
use "Data\Zurich_final.dta", replace

* Drop observations after first trial
sum date if ivote_poss == 1
drop if date >= r(min)

* Mean by treatment group
collapse turnout, by(ivotemun date year month day)

* Small ticks for Apr 1st, Jul 1st and Oct 1st
forval i = 2001/2005 { 
di d(1apr`i') " " _c 
di d(1jul`i') " " _c 
di d(1oct`i') " " _c
}

twoway 	(connected turnout date if ivotemun == 1, ///
			sort lpattern(solid) lcolor(gs0) mcolor(gs0) msymbol(circle)) ///
		(connected turnout date if ivotemun == 0, ///
			sort lpattern(dash) lcolor(gs8) mcolor(gs8) msymbol(circle)), ///
		xscale(nofextend) ///
		xlabel(14976 15341 15706 16071 16437 ///
				16071 16437	16802, nogrid angle(forty_five) value) ///
		xmlabel(15066 15157 15249 15431 15522 15614 15796 15887 15979 16162 16253 16345 ///
				16527 16618 16710 ///
				, nolabels) ///
		xtitle("Time", margin(small)) ///
		yscale(nofextend) ///
		ylabel(20(10)80, angle(horizontal) nogrid) ///
		ymlabel(22.5(2.5)77.5, nolabels) ///
		ytitle("Turnout (%)", margin(small)) ///
		title("Zurich", margin(bottom) size(vlarge)) ///
		scheme(s2mono) graphregion(fcolor(white) lcolor(white)) ///
		legend(order(1 "I-voting" 2 "No i-voting") rows(1) pos(12) region(lcolor(white)))
graph export "Figures\paralleltrends_ZH_turnout.pdf", replace



***********
** Figure 3
***********

* Geneva
use "Data\Geneva_final.dta", replace
gen yearXivote_poss = year * ivote_poss
xtreg turnout ivote_poss year yearXivote_poss ///
	i.date unittrend6601-unittrend6644 unittrendsq6601-unittrendsq6644 ///
	, ///
	fe cl(municipality_code) i(municipality_code)

matrix b = e(b)
matrix V = e(V)
scalar b1 = b[1,1]
scalar b3 = b[1,3]
scalar varb1 = V[1,1]
scalar varb3 = V[3,3]
scalar covb1b3 = V[1,3]
scalar covb2b3 = V[2,3]

sum year if ivote_poss == 1
gen calyear = r(min)-1+_n
replace calyear = . if calyear > r(max)

gen conb = b1 + b3 * calyear
gen conse = sqrt(varb1+varb3*(calyear^2)+2*covb1b3*calyear)
gen a=1.96*conse
gen upper=conb + a
gen lower=conb - a

bysort year: egen trialspy = sum(ivote_poss)
gen trialcount = .
forvalues i = 2001(1)2014 {
sum trialspy if year == `i'
replace trialcount = r(mean) if calyear == `i'
}
gen zero = 0

graph twoway bar trialcount calyear, color(gs14) yaxis(2) ///
	|| line conb calyear, clpattern(solid) clwidth(medthick) clcolor (black) sort yaxis(1) ///
	|| line upper calyear, clpattern(dash) clwidth(medthin) clcolor(black) sort yaxis(1) ///
	|| line lower calyear, clpattern(dash) clwidth(medthin) clcolor(black) sort yaxis(1) ///
	|| line zero calyear, clpattern(solid) clwidth(thin) clcolor(gs0) sort yaxis(1) ///
	, ///
	xscale(noextend) yscale(noextend alt) yscale(noextend alt axis(2)) ///
	xlabel(2004(2)2014, nogrid angle(forty_five)) xmlabel(2004(1)2014, nolabels) ///
	ylabel(-4(2)4, nogrid angle(horizontal) axis(1)) ymlabel(-4(1)4, nolabels angle(horizontal) axis(1)) ///
	ylabel(0(20)80, axis(2) angle(horizontal) nogrid) ymlabel(0(10)80, axis(2) angle(horizontal) nolabels) ///
	legend(off) ///
	xtitle("Calendar year") ///
	ytitle("Conditional effect of i-voting on turnout", axis(1)) ytitle("Number of i-voting trials", axis(2) margin(small)) ///
	title("Geneva", margin(bottom) size(vlarge)) ///
	scheme(s2mono) graphregion(fcolor(white) lcolor(white)) ///
	xsize(9) ysize(6)
graph export "Figures\Interactions_year_GE.pdf", replace



* Zurich
use "Data\Zurich_final.dta", replace
gen yearXivote_poss = year * ivote_poss
xtreg turnout ivote_poss year yearXivote_poss ///
	i.date unittrend1-unittrend251 unittrendsq1-unittrendsq251 ///
	, ///
	fe cl(municipality_code) i(municipality_code)

matrix b = e(b)
matrix V = e(V)
scalar b1 = b[1,1]
scalar b3 = b[1,3]
scalar varb1 = V[1,1]
scalar varb3 = V[3,3]
scalar covb1b3 = V[1,3]
scalar covb2b3 = V[2,3]

sum year if ivote_poss == 1
gen calyear = r(min)-1+_n
replace calyear = . if calyear > r(max)

gen conb = b1 + b3 * calyear
gen conse = sqrt(varb1+varb3*(calyear^2)+2*covb1b3*calyear)
gen a=1.96*conse
gen upper=conb + a
gen lower=conb - a

bysort year: egen trialspy = sum(ivote_poss)
gen trialcount = .
forvalues i = 2001(1)2011 {
sum trialspy if year == `i'
replace trialcount = r(mean) if calyear == `i'
}
gen zero = 0

graph twoway bar trialcount calyear, color(gs14) yaxis(2) ///
	|| line conb calyear, clpattern(solid) clwidth(medthick) clcolor (black) sort yaxis(1) ///
	|| line upper calyear, clpattern(dash) clwidth(medthin) clcolor(black) sort yaxis(1) ///
	|| line lower calyear, clpattern(dash) clwidth(medthin) clcolor(black) sort yaxis(1) ///
	|| line zero calyear, clpattern(solid) clwidth(thin) clcolor(gs0) sort yaxis(1) ///
	, ///
	xscale(noextend) yscale(noextend alt) yscale(noextend alt axis(2)) ///
	xlabel(2005(1)2011, nogrid angle(forty_five)) ///
	ylabel(-4(2)4, axis(1) angle(horizontal) nogrid) ymlabel(-4(1)4, axis(1) angle(horizontal) nolabels) ///
	ylabel(0(20)80, axis(2) angle(horizontal) nogrid) ymlabel(0(10)80, axis(2) angle(horizontal) nolabels) ///
	legend(off) ///
	xtitle("Calendar year") ///
	ytitle("Conditional effect of i-voting on turnout", axis(1)) ytitle("Number of i-voting trials", axis(2) margin(small)) ///
	title("Zurich", margin(bottom) size(vlarge)) ///
	scheme(s2mono) graphregion(fcolor(white) lcolor(white)) ///
	xsize(9) ysize(6)
graph export "Figures\Interactions_year_ZH.pdf", replace




**********************
** Supplement: Table 2
**********************

estimates replay m1 m2 m3 m4




**********************
** Supplement: Table 3
**********************


* (1) Geneva (first three trials separate)
use "Data\Geneva_final.dta", replace
gen firstthree = ivote_poss
replace firstthree = 0 if trialno > 2 & trialno != .
gen allother = ivote_poss
replace allother = 0 if firstthree == 1
xtreg turnout firstthree allother ///
	i.date unittrend6601-unittrend6644 unittrendsq6601-unittrendsq6644 ///
	, ///
	fe cl(municipality_code) i(municipality_code)
test firstthree = allother
	
* (2) Zurich (first three trials separate)	
use "Data\Zurich_final.dta", replace
gen firstthree = ivote_poss
replace firstthree = 0 if trialno > 2 & trialno != .
gen allother = ivote_poss
replace allother = 0 if firstthree == 1
xtreg turnout firstthree allother ///
	i.date unittrend1-unittrend251 unittrendsq1-unittrendsq251 ///
	, ///
	fe cl(municipality_code) i(municipality_code) 
test firstthree = allother

* (3) Zurich (exclude Winterthur & Zurich)
use "Data\Zurich_final.dta", replace
xtreg turnout ivote_poss ///
	i.date unittrend1-unittrend251 unittrendsq1-unittrendsq251 ///
	if partialtreat != 1, ///
	fe cl(municipality_code) i(municipality_code) 	




***********************
** Supplement: Figure 1
***********************

* Geneva
use "Data\Geneva_final.dta", replace

* Drop observations after first post-big gap (2005-2008) trial
drop if date >= td(30nov2008)

* Drop the two trials before big gap
drop if date == td(26sep2004)
drop if date == td(28nov2004)

* Prepare variables to store betas and ses of fake treatments
gen beta = .
gen se = .

* Define fake treatments for treated units
	* First referendum day cannot be faketreated by definition
forvalues i = 1/100 {
qui: sum date
qui: local min = r(min)
qui: local max = r(max)
qui: local seed = 761568 + `i'
qui: set seed `seed'
qui: gen random = runiform(`min'+1,`max') if date == `min' & ivotemun == 1
qui: bysort municipality_code: egen meanrandom = mean(random)
qui: gen faketreat`i' = 0
qui: replace faketreat`i' = 1 if date >= meanrandom

* Re-estimate model and save results
qui: xtreg turnout faketreat`i' ///
	i.date unittrend6601-unittrend6644 unittrendsq6601-unittrendsq6644 ///
	if year >= 2001, ///
	fe cl(municipality_code) i(municipality_code)
 
qui: mat b = r(table)
qui: replace beta = b[1,1] in `i' 
qui: replace se = b[2,1] in `i'
qui: drop random meanrandom
di "." _c
}

* 95% confidence intervals
gen upperci = beta + 1.96 * se
gen lowerci = beta - 1.96 * se

* count
gen count = _n if beta != .

* Graph results
twoway (rspike upperci lowerci count, lcolor(gs0) lwidth(thin)) ///
		(scatter beta count, msymbol(O) msize(small) mcolor(gs0)) , ///
		yline(0, lcolor(gs0) lwidth(thin)) ///
		xscale(nofextend) ///
		xlabel(0(10)100, nogrid) ///
		xmlabel(1(1)100, nolabels) ///
		xtitle("Model", margin(small)) ///
		yscale(nofextend) ///
		ylabel(-5(2.5)5, angle(horizontal) nogrid) ///
		ymlabel(-5(.5)5, nolabels) ///
		ytitle("Placebo effect on turnout (%)", margin(small)) ///
		title("Geneva", margin(bottom) size(vlarge)) ///
		scheme(s2mono) graphregion(fcolor(white) lcolor(white)) legend(off)		
graph export "Figures\Placebo_GE.pdf", replace

* Share of significant models
gen significant = 1 if beta != .
replace significant = 0 if upperci > 0 & lowerci < 0
tab significant



* Zurich
use "Data\Zurich_final.dta", replace

* Drop observations after first trial
sum date if ivote_poss == 1
drop if date >= r(min)

* Prepare variables to store betas and ses of fake treatments
gen beta = .
gen se = .

* Define fake treatments for treated units
	* First referendum day cannot be faketreated by definition
forvalues i = 1/100 {
qui: sum date
qui: local min = r(min)
qui: local max = r(max)
qui: local seed = 156862321 + `i'
qui: set seed `seed'
qui: gen random = runiform(`min',`max') if date == `min' & ivotemun == 1
qui: bysort municipality_code: egen meanrandom = mean(random)
qui: gen faketreat`i' = 0
qui: replace faketreat`i' = 1 if date >= meanrandom

* Re-estimate model and save results
qui: xtreg turnout faketreat`i' ///
	i.date unittrend1-unittrend251 unittrendsq1-unittrendsq251 ///
	if year >= 2001, ///
	fe cl(municipality_code) i(municipality_code) 

qui: mat b = r(table)
qui: replace beta = b[1,1] in `i' 
qui: replace se = b[2,1] in `i'
qui: drop random meanrandom
di "." _c
}

* 95% confidence intervals
gen upperci = beta + 1.96 * se
gen lowerci = beta - 1.96 * se

* Count
gen count = _n if beta != .

* Graph results
twoway (rspike upperci lowerci count, lcolor(gs0) lwidth(thin)) ///
		(scatter beta count, msymbol(O) msize(small) mcolor(gs0)) , ///
		yline(0, lcolor(gs0) lwidth(thin)) ///
		xscale(nofextend) ///
		xlabel(0(10)100, nogrid) ///
		xmlabel(1(1)100, nolabels) ///
		xtitle("Model", margin(small)) ///
		yscale(nofextend) ///
		ylabel(-5(2.5)5, angle(horizontal) nogrid) ///
		ymlabel(-5(.5)5, nolabels) ///
		ytitle("Placebo effect on turnout (%)", margin(small)) ///
		title("Zurich", margin(bottom) size(vlarge)) ///
		scheme(s2mono) graphregion(fcolor(white) lcolor(white)) legend(off)		
graph export "Figures\Placebo_ZH.pdf", replace

* Share of significant models
gen significant = 1 if beta != .
replace significant = 0 if upperci > 0 & lowerci < 0
tab significant



***********************
** Supplement: Figure 2
***********************

* Geneva
use "Data\Geneva_final.dta", replace
gen yearcount = year - 2000
gen yearcountsq = yearcount * yearcount
gen yearcountXivote_poss = yearcount * ivote_poss
gen yearcountsqXivote_poss = yearcountsq * ivote_poss
xtreg turnout ivote_poss yearcount yearcountsq yearcountXivote_poss yearcountsqXivote_poss ///
	i.date unittrend6601-unittrend6644 unittrendsq6601-unittrendsq6644 ///
	, ///
	fe cl(municipality_code) i(municipality_code)

matrix b = e(b)
matrix V = e(V)
scalar b1 = b[1,1]
scalar b4 = b[1,4]
scalar b5 = b[1,5]
scalar varb1 = V[1,1]
scalar varb4 = V[4,4]
scalar varb5 = V[5,5]
scalar covb1b4 = V[1,4]
scalar covb1b5 = V[1,5]
scalar covb4b5 = V[4,5]

sum year if ivote_poss == 1
gen calyear = r(min)-1+_n
replace calyear = . if calyear > r(max)
gen MV = calyear - 2000

gen conb = b1 + b4 * MV + b5 * MV^2
gen conse = sqrt(varb1+varb4*MV^2+varb5*MV^4+covb1b4*2*MV+covb1b5*2*MV^2+covb4b5*2*MV^3)
gen a=1.96*conse
gen upper=conb + a
gen lower=conb - a

bysort year: egen trialspy = sum(ivote_poss)
gen trialcount = .
forvalues i = 2001(1)2014 {
sum trialspy if year == `i'
replace trialcount = r(mean) if calyear == `i'
}
gen zero = 0

graph twoway bar trialcount calyear, color(gs14) yaxis(2) ///
	|| line conb calyear, clpattern(solid) clwidth(medthick) clcolor (black) sort yaxis(1) ///
	|| line upper calyear, clpattern(dash) clwidth(medthin) clcolor(black) sort yaxis(1) ///
	|| line lower calyear, clpattern(dash) clwidth(medthin) clcolor(black) sort yaxis(1) ///
	|| line zero calyear, clpattern(solid) clwidth(thin) clcolor(gs0) sort yaxis(1) ///
	, ///
	xscale(noextend) yscale(noextend alt) yscale(noextend alt axis(2)) ///
	xlabel(2004(2)2014, nogrid angle(forty_five)) xmlabel(2004(1)2014, nolabels) ///
	ylabel(-4(2)4, nogrid angle(horizontal) axis(1)) ymlabel(-4(1)4, nolabels angle(horizontal) axis(1)) ///
	ylabel(0(20)80, axis(2) angle(horizontal) nogrid) ymlabel(0(10)80, axis(2) angle(horizontal) nolabels) ///
	legend(off) ///
	xtitle("Calendar year") ///
	ytitle("Conditional effect of i-voting on turnout", axis(1)) ytitle("Number of i-voting trials", axis(2) margin(small)) ///
	title("Geneva", margin(bottom) size(vlarge)) ///
	scheme(s2mono) graphregion(fcolor(white) lcolor(white)) ///
	xsize(9) ysize(6)
graph export "Figures\Interactions_yearsq_GE.pdf", replace



* Zurich
use "Data\Zurich_final.dta", replace
gen yearcount = year - 2000
gen yearcountsq = yearcount * yearcount
gen yearcountXivote_poss = yearcount * ivote_poss
gen yearcountsqXivote_poss = yearcountsq * ivote_poss
xtreg turnout ivote_poss yearcount yearcountsq yearcountXivote_poss yearcountsqXivote_poss ///
	i.date unittrend1-unittrend251 unittrendsq1-unittrendsq251 ///
	, ///
	fe cl(municipality_code) i(municipality_code)

matrix b = e(b)
matrix V = e(V)
scalar b1 = b[1,1]
scalar b4 = b[1,4]
scalar b5 = b[1,5]
scalar varb1 = V[1,1]
scalar varb4 = V[4,4]
scalar varb5 = V[5,5]
scalar covb1b4 = V[1,4]
scalar covb1b5 = V[1,5]
scalar covb4b5 = V[4,5]

sum year if ivote_poss == 1
gen calyear = r(min)-1+_n
replace calyear = . if calyear > r(max)
gen MV = calyear - 2000

gen conb = b1 + b4 * MV + b5 * MV^2
gen conse = sqrt(varb1+varb4*MV^2+varb5*MV^4+covb1b4*2*MV+covb1b5*2*MV^2+covb4b5*2*MV^3)
gen a=1.96*conse
gen upper=conb + a
gen lower=conb - a

bysort year: egen trialspy = sum(ivote_poss)
gen trialcount = .
forvalues i = 2001(1)2011 {
sum trialspy if year == `i'
replace trialcount = r(mean) if calyear == `i'
}
gen zero = 0

graph twoway bar trialcount calyear, color(gs14) yaxis(2) ///
	|| line conb calyear, clpattern(solid) clwidth(medthick) clcolor (black) sort yaxis(1) ///
	|| line upper calyear, clpattern(dash) clwidth(medthin) clcolor(black) sort yaxis(1) ///
	|| line lower calyear, clpattern(dash) clwidth(medthin) clcolor(black) sort yaxis(1) ///
	|| line zero calyear, clpattern(solid) clwidth(thin) clcolor(gs0) sort yaxis(1) ///
	, ///
	xscale(noextend) yscale(noextend alt) yscale(noextend alt axis(2)) ///
	xlabel(2005(1)2011, nogrid angle(forty_five)) ///
	ylabel(-4(2)4, axis(1) angle(horizontal) nogrid) ymlabel(-4(1)4, axis(1) angle(horizontal) nolabels) ///
	ylabel(0(20)80, axis(2) angle(horizontal) nogrid) ymlabel(0(10)80, axis(2) angle(horizontal) nolabels) ///
	legend(off) ///
	xtitle("Calendar year") ///
	ytitle("Conditional effect of i-voting on turnout", axis(1)) ytitle("Number of i-voting trials", axis(2) margin(small)) ///
	title("Zurich", margin(bottom) size(vlarge)) ///
	scheme(s2mono) graphregion(fcolor(white) lcolor(white)) ///
	xsize(9) ysize(6)
graph export "Figures\Interactions_yearsq_ZH.pdf", replace



***********************
** Supplement: Figure 3
***********************

use "Data\Geneva_final.dta", replace
gen hackattack = 0
replace hackattack = 1 if date >= td(30jun2013)
gen hackattackXivote_poss = ivote_poss * hackattack
xtreg turnout ivote_poss hackattack hackattackXivote_poss ///
	i.date unittrend6601-unittrend6644 unittrendsq6601-unittrendsq6644 ///
	, ///
	fe cl(municipality_code) i(municipality_code)

gen MV = _n - 1 if _n < 3

matrix b = e(b)
matrix V = e(V)
scalar b1 = b[1,1]
scalar b3 = b[1,3]
scalar varb1 = V[1,1]
scalar varb3 = V[3,3]
scalar covb1b3 = V[1,3]
scalar covb2b3 = V[2,3]

gen conb = b1 + b3 * MV
gen conse = sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV)
gen a=1.96*conse
gen upper=conb + a
gen lower=conb - a

bysort hackattack: egen trialsphack = sum(ivote_poss)
gen trialcount = .
forvalues i = 0/1 {
sum trialsphack if hackattack == `i'
replace trialcount = r(mean) if MV == `i'
}
gen zero = 0
sort MV
replace MV = -1 if _n == 3
replace MV = 2 if _n == 4
	

twoway (bar trialcount MV, color(gs14) barwidth(0.25) yaxis(2)) ///
	   (rspike upper lower MV, lcolor(gs0) lwidth(medium)) ///
	   (scatter conb MV, msymbol(O) msize(medium) mcolor(gs0)) ///
	   (line zero MV, clpattern(solid) clwidth(thin) clcolor(gs0) sort yaxis(1)) ///
	   , ///
		xscale(noline range(-1 2)) yscale(noextend alt) yscale(noextend alt axis(2)) ///
		xlabel(0 "Before the attack" 1 "After the attack", nogrid notick angle(forty_five)) ///
		xtitle("") ///
		ylabel(-2(1)2, axis(1) angle(horizontal) nogrid) ymlabel(-2(0.5)2, axis(1) angle(horizontal) nolabels) ///
		ylabel(0(50)200, axis(2) angle(horizontal) nogrid) ymlabel(0(25)200, axis(2) angle(horizontal) nolabels) ///
		ytitle("Conditional effect of i-voting on turnout", axis(1)) ytitle("Number of i-voting trials", axis(2) margin(small)) ///
		title("Geneva", margin(bottom) size(vlarge)) ///
		legend(off) ///
		scheme(s2mono) graphregion(fcolor(white) lcolor(white)) ///
		xsize(4) ysize(6)	
graph export "Figures\Hackattack_GE.pdf", replace




***********************
** Supplement: Figure 4
***********************


* Geneva
use "Data\Geneva_final.dta", replace
gen interrupted = 0
replace interrupted = 1 if gapcount != . & gapcount > 0
gen interruptedXivote_poss = interrupted * ivote_poss
xtreg turnout ivote_poss interrupted interruptedXivote_poss ///
	i.date unittrend6601-unittrend6644 unittrendsq6601-unittrendsq6644 ///
	, ///
	fe cl(municipality_code) i(municipality_code)

	
	
gen MV = _n - 1 if _n < 3

matrix b = e(b)
matrix V = e(V)
scalar b1 = b[1,1]
scalar b3 = b[1,3]
scalar varb1 = V[1,1]
scalar varb3 = V[3,3]
scalar covb1b3 = V[1,3]
scalar covb2b3 = V[2,3]

gen conb = b1 + b3 * MV
gen conse = sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV)
gen a=1.96*conse
gen upper=conb + a
gen lower=conb - a

bysort interrupted: egen trialspgap = sum(ivote_poss)
gen trialcount = .
forvalues i = 0/1 {
sum trialspgap if interrupted == `i'
replace trialcount = r(mean) if MV == `i'
}
gen zero = 0
sort MV
replace MV = -1 if _n == 3
replace MV = 2 if _n == 4
	

twoway (bar trialcount MV, color(gs14) barwidth(0.25) yaxis(2)) ///
	   (rspike upper lower MV, lcolor(gs0) lwidth(medium)) ///
	   (scatter conb MV, msymbol(O) msize(medium) mcolor(gs0)) ///
	   (line zero MV, clpattern(solid) clwidth(thin) clcolor(gs0) sort yaxis(1)) ///
	   , ///
		xscale(noline range(-1 2)) yscale(noextend alt range(-2.1 2.1)) yscale(noextend alt axis(2)) ///
		xlabel(0 "No gap" 1 "≥ 1 gap", nogrid notick angle(forty_five)) ///
		xtitle("") ///
		ylabel(-2(1)2, axis(1) angle(horizontal) nogrid) ymlabel(-2(0.5)2, axis(1) angle(horizontal) nolabels) ///
		ylabel(0(50)300, axis(2) angle(horizontal) nogrid) ymlabel(0(25)300, axis(2) angle(horizontal) nolabels) ///
		ytitle("Conditional effect of i-voting on turnout", axis(1)) ytitle("Number of i-voting trials", axis(2) margin(small)) ///
		title("Geneva", margin(bottom) size(vlarge)) ///
		legend(off) ///
		scheme(s2mono) graphregion(fcolor(white) lcolor(white)) ///
		xsize(4) ysize(6)
graph export "Figures\Gaps_GE.pdf", replace

	
	
* Zurich
use "Data\Zurich_final.dta", replace
gen interrupted = 0
replace interrupted = 1 if gapcount != . & gapcount > 0
gen interruptedXivote_poss = interrupted * ivote_poss
xtreg turnout ivote_poss interrupted interruptedXivote_poss ///
	i.date unittrend1-unittrend251 unittrendsq1-unittrendsq251 ///
	, ///
	fe cl(municipality_code) i(municipality_code)
	
gen MV = _n - 1 if _n < 3

matrix b = e(b)
matrix V = e(V)
scalar b1 = b[1,1]
scalar b3 = b[1,3]
scalar varb1 = V[1,1]
scalar varb3 = V[3,3]
scalar covb1b3 = V[1,3]
scalar covb2b3 = V[2,3]

gen conb = b1 + b3 * MV
gen conse = sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV)
gen a=1.96*conse
gen upper=conb + a
gen lower=conb - a

bysort interrupted: egen trialspgap = sum(ivote_poss)
gen trialcount = .
forvalues i = 0/1 {
sum trialspgap if interrupted == `i'
replace trialcount = r(mean) if MV == `i'
}
gen zero = 0
sort MV
replace MV = -1 if _n == 3
replace MV = 2 if _n == 4
	

twoway (bar trialcount MV, color(gs14) barwidth(0.25) yaxis(2)) ///
	   (rspike upper lower MV, lcolor(gs0) lwidth(medium)) ///
	   (scatter conb MV, msymbol(O) msize(medium) mcolor(gs0)) ///
	   (line zero MV, clpattern(solid) clwidth(thin) clcolor(gs0) sort yaxis(1)) ///
	   , ///
		xscale(noline range(-1 2)) yscale(noextend alt) yscale(noextend alt axis(2)) ///
		xlabel(0 "No gap" 1 "≥ 1 gap", nogrid notick angle(forty_five)) ///
		xtitle("") ///
		ylabel(-5(1)2, axis(1) angle(horizontal) nogrid) ymlabel(-2(0.5)2, axis(1) angle(horizontal) nolabels) ///
		ylabel(0(25)100, axis(2) angle(horizontal) nogrid) ymlabel(0(5)100, axis(2) angle(horizontal) nolabels) ///
		ytitle("Conditional effect of i-voting on turnout", axis(1)) ytitle("Number of i-voting trials", axis(2) margin(small)) ///
		title("Zurich", margin(bottom) size(vlarge)) ///
		legend(off) ///
		scheme(s2mono) graphregion(fcolor(white) lcolor(white)) ///
		xsize(4) ysize(6)
graph export "Figures\Gaps_ZH.pdf", replace



* Close log
log close	
	
